/**
 * Copyright (C) 2016-2017  Dušan Vejnovič  <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dtabs.demo.ui.context;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.util.logging.Level;
import java.util.logging.Logger;

import org.dussan.vaadin.dtabs.DTabs;
import org.vaadin.aceeditor.AceEditor;
import org.vaadin.aceeditor.AceMode;
import org.vaadin.aceeditor.AceTheme;

import com.vaadin.ui.CustomLayout;
import com.vaadin.ui.Panel;
import com.vaadin.ui.VerticalLayout;

public abstract class TabContext
    extends VerticalLayout
{

    private static final long serialVersionUID = 7447580571029014661L;

    private static final String TABS_CODE = "<table style='height:100%;width:100%;'><tr><td style='height:1px;'>"
        + "<div location='tabs'></div></td></tr><tr><td style='height:100%;'>"
        + "<div style='height:100%;' location='code'></div></td></tr></table>";

    private boolean isAttached = false;

    public TabContext()
    {
        setSizeFull();
        setSpacing( true );
        setStyleName( "tabCode" );
    }

    protected abstract void init();

    protected void setTab( DTabs tab, String text )
    {
        Panel code = new Panel( "Code for dTabs Demo" );
        AceEditor editor = new AceEditor();
        editor.setSizeFull();
        editor.setMode( AceMode.java );
        editor.setTheme( AceTheme.eclipse );
        editor.setValue( text );
        editor.setReadOnly( true );
        code.setContent( editor );
        code.setSizeFull();

        try
        {
            CustomLayout customLayout = null;
            customLayout = new CustomLayout( new ByteArrayInputStream( TABS_CODE.getBytes() ) );
            customLayout.setSizeFull();
            customLayout.addComponent( tab, "tabs" );
            customLayout.addComponent( code, "code" );
            addComponent( customLayout );
        }
        catch ( IOException e )
        {
            Logger.getLogger( TabContext.class.getName() )
                  .log( Level.WARNING, e.getLocalizedMessage() );
        }
    }

    @Override
    public void attach()
    {
        super.attach();
        if ( !isAttached )
        {
            isAttached = true;
            init();
            getParent().setSizeFull();
        }
    }

}
